/*
 * $Id: acconfig.h,v 1.1 2000/09/11 17:48:19 grubba Exp $
 */

#ifndef IMAGE_GIF_CONFIG_H
#define IMAGE_GIF_CONFIG_H

@TOP@

/* Define this to enable gif support */
#undef WITH_GIF

/* Define if you want lzw code to generate only rle packing */
#undef GIF_LZW_RLE

@BOTTOM@

#endif /* !IMAGE_GIF_CONFIG_H */
